@@ -63,8 +63,6 @@ class ACall:
         self.session = None
 
     async def call(self, path, method="GET", headers={}, params={}, json={}, no_auth=False):
-        #print(method + " request at " + path)
-
         if no_auth:
             return await self._call(path, method, headers, params, json)
 
@@ -100,6 +98,7 @@ class ACall:
 
         resp = {"status": status, "data": json}
 
+        print(method + " request at " + path + " -- " + status)
         raise_for_status(resp)
         return resp
 
@@ -141,6 +140,7 @@ class ACall:
 
             resp = {"status": status, "data": json}
 
+            print(method + " request at " + path + " -- " + status)
             raise_for_status(resp)
             return resp
 
@@ -160,8 +160,6 @@ class Call:
         self.b64_auth = None
 
     def call(self, path, method="GET", headers={}, params={}, json={}, no_auth=False):
-        #print(method + " request at " + path)
-
         headers["user-agent"] = ""
 
         if no_auth:
@@ -193,11 +191,13 @@ class Call:
             try: json = resp.json()
             except: json = None
 
+            print(method + " request at " + path + " -- " + str(resp.status_code))
             resp = {"status": resp.status_code, "data": json if not json == None else resp.content}
 
             raise_for_status(resp)
             return resp
 
+        print(method + " request at " + path + " -- " + str(resp.status_code))
         resp = {"status": resp.status_code, "data": resp.json()}
 
         raise_for_status(resp)
@@ -226,11 +226,13 @@ class Call:
             try: json = resp.json()
             except: json = None
 
+            print(method + " request at " + path + " -- " + str(resp.status_code))
             resp = {"status": resp.status_code, "data": json if not json == None else resp.content}
 
             raise_for_status(resp)
             return resp
 
+        print(method + " request at " + path + " -- " + str(resp.status_code))
         resp = {"status": resp.status_code, "data": resp.json()}
 
         raise_for_status(resp)
